summaryrefslogtreecommitdiffstats
path: root/chrome/browser/cocoa/content_exceptions_window_controller.h
diff options
context:
space:
mode:
authorjochen@chromium.org <jochen@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-04-08 09:18:29 +0000
committerjochen@chromium.org <jochen@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-04-08 09:18:29 +0000
commit0314ae017cc069f72240401b52f6e37403c581ca (patch)
tree55f61e3ca4f6670648038cae338f82cddc2625bb /chrome/browser/cocoa/content_exceptions_window_controller.h
parent3184770afa9cbcf49680bab5046c57a7ca035388 (diff)
downloadchromium_src-0314ae017cc069f72240401b52f6e37403c581ca.zip
chromium_src-0314ae017cc069f72240401b52f6e37403c581ca.tar.gz
chromium_src-0314ae017cc069f72240401b52f6e37403c581ca.tar.bz2
Implement patterns for content setting exceptions.
BUG=37394 TEST=unit_tests + manual Review URL: http://codereview.chromium.org/1567010 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@43936 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/cocoa/content_exceptions_window_controller.h')
-rw-r--r--chrome/browser/cocoa/content_exceptions_window_controller.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/chrome/browser/cocoa/content_exceptions_window_controller.h b/chrome/browser/cocoa/content_exceptions_window_controller.h
index c3344ca..91a5b33 100644
--- a/chrome/browser/cocoa/content_exceptions_window_controller.h
+++ b/chrome/browser/cocoa/content_exceptions_window_controller.h
@@ -40,9 +40,9 @@ class UpdatingContentSettingsObserver;
// is used to suppress updates at bad times.
BOOL updatesEnabled_;
// This is non-NULL only while a new element is being added and its host
// is being edited.
- scoped_ptr<HostContentSettingsMap::HostSettingPair> newException_;
+ scoped_ptr<HostContentSettingsMap::PatternSettingPair> newException_;
}
// Shows or makes frontmost the content exceptions window for |settingsType|.
@@ -40,9 +40,9 @@ class UpdatingContentSettingsObserver;
// is used to suppress updates at bad times.
BOOL updatesEnabled_;
- // This is non-NULL only while a new element is being added and its host
+ // This is non-NULL only while a new element is being added and its pattern
// is being edited.